@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,7 +100,8 @@ static void replace_and_free_with_quoted_string(std::string& command, size_t& in
 //-----------------------------------------------------------------------------
 
 Launcher::Launcher(GarconMenuItem* item) :
-	m_item(item)
+	m_item(item),
+	m_search_flags(0)
 {
 	// Fetch icon
 	const gchar* icon = garcon_menu_item_get_icon_name(m_item);
@@ -149,6 +150,12 @@ Launcher::Launcher(GarconMenuItem* item) :
 		generic_name = "";
 	}
 
+	if (!wm_settings->launcher_show_name && !exo_str_is_empty(generic_name))
+	{
+		std::swap(name, generic_name);
+	}
+	m_display_name = name;
+
 	const gchar* details = garcon_menu_item_get_comment(m_item);
 	if (!details || !g_utf8_validate(details, -1, NULL))
 	{
@@ -157,7 +164,6 @@ Launcher::Launcher(GarconMenuItem* item) :
 
 	// Create display text
 	const gchar* direction = (gtk_widget_get_default_direction() != GTK_TEXT_DIR_RTL) ? "\342\200\216" : "\342\200\217";
-	m_display_name = (wm_settings->launcher_show_name || exo_str_is_empty(generic_name)) ? name : generic_name;
 	if (wm_settings->launcher_show_description)
 	{
 		set_text(g_markup_printf_escaped("%s<b>%s</b>\n%s%s", direction, m_display_name, direction, details));
@@ -166,9 +172,11 @@ Launcher::Launcher(GarconMenuItem* item) :
 	{
 		set_text(g_markup_printf_escaped("%s%s", direction, m_display_name));
 	}
+	set_tooltip(details);
 
 	// Create search text for display name
 	m_search_name = normalize(m_display_name);
+	m_search_generic_name = normalize(generic_name);
 	m_search_comment = normalize(details);
 
 	// Create search text for command
@@ -270,29 +278,53 @@ void Launcher::run(GdkScreen* screen) const
 
 //-----------------------------------------------------------------------------
 
-int Launcher::search(const Query& query)
+guint Launcher::search(const Query& query)
 {
-	int match = query.match(m_search_name);
-	if (match != G_MAXINT)
+	// Prioritize matches in favorites and recent, then favories, and then recent
+	const guint flags = 3 - m_search_flags;
+
+	// Sort matches in names first
+	guint match = query.match(m_search_name);
+	if (match != G_MAXUINT)
 	{
-		return match;
+		return match | flags | 0x400;
 	}
 
-	// Sort matches in executables after matches in names
-	match = query.match(m_search_command);
-	if (match != G_MAXINT)
+	match = query.match(m_search_generic_name);
+	if (match != G_MAXUINT)
 	{
-		match += 10;
-		return match;
+		return match | flags | 0x800;
 	}
 
-	// Sort matches in comments after matches in names
+	// Sort matches in comments next
 	match = query.match(m_search_comment);
-	if (match != G_MAXINT)
+	if (match != G_MAXUINT)
 	{
-		match += 20;
+		return match | flags | 0x1000;
+	}
+
+	// Sort matches in executables last
+	match = query.match(m_search_command);
+	if (match != G_MAXUINT)
+	{
+		return match | flags | 0x2000;
+	}
+
+	return G_MAXUINT;
+}
+
+//-----------------------------------------------------------------------------
+
+void Launcher::set_flag(SearchFlag flag, bool enabled)
+{
+	if (enabled)
+	{
+		m_search_flags |= flag;
+	}
+	else
+	{
+		m_search_flags &= ~flag;
 	}
-	return match;
 }
 
 //-----------------------------------------------------------------------------
