@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -93,16 +93,12 @@ private:
 private:
 	GtkWindow* m_window;
 
-	GtkBox* m_window_box;
-	GtkWidget* m_window_contents;
-
 	GtkBox* m_vbox;
 	GtkBox* m_title_box;
 	GtkBox* m_commands_box;
 	GtkBox* m_search_box;
 	GtkBox* m_contents_box;
 	GtkBox* m_panels_box;
-	GtkBox* m_sidebar_box;
 
 	ProfilePicture* m_profilepic;
 	GtkLabel* m_username;
@@ -121,9 +117,11 @@ private:
 	Page* m_default_page;
 
 	GtkScrolledWindow* m_sidebar;
+	GtkBox* m_sidebar_buttons;
 	SectionButton* m_favorites_button;
 	SectionButton* m_recent_button;
 	SectionButton* m_default_button;
+	GtkSizeGroup* m_sidebar_size_group;
 
 	GdkRectangle m_geometry;
 	bool m_layout_left;
